@@ -3,4 +3,4 @@ from django.apps import AppConfig
 
 class PdfembedConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
-    name = 'pdfembed'
+    name = 'djangocms_pdfembed'
